Flickr Metadata Maps

### Information

Explore the locations where millions of Flickr photos were taken.

This application retrieves Flickr metadata stored in a database and displays the locations on a GeoJS map. Use the controls to trigger a new lookup, or change the visualization properties.

Hover over a location to see more information from that photo's metadata.

There doesn't seem to be a Mongo instance at %server%, with database %db% and collection %coll%, or there is no data there, or PyMongo is not installed. Try these steps to get things working:

1. Set up MongoDB. To set up a Mongo server you can consult the MongoDB documentation. It is generally as straightforward as installing it via a package manager, then launching the ``mongod`` program, or starting it via your local service manager.

2. Install PyMongo. This application uses the PyMongo Python package to interact with the Mongo server. You can install it like this:

   `pip install pymongo`

   (Be sure to use the same `pip` that you used to install Tangelo. For example, if you built Tangelo from source, then you should use `<tangelo-source-dir>/venv/bin/pip`.)

3. Get Flickr photo data. Download the hosted Flickr data file.

   You can also download data from Flickr yourself. To do this you will need a Flickr API key. Armed with a key, you can run the `get-flickr-data.py` script, which can be found at `/usr/share/tangelo/data/get-flickr-data.py`. You can run it like this:

   `get-flickr-data.py <API key> <max photos to retrieve> flickr_paris.json`

   The hosted version mentioned above was generated with this script, with a max count argument of 1000.

4. Upload the data to Mongo. You can use this command to place the photo data into your MongoDB instance:

   `mongoimport -d tangelo -c flickr_paris --jsonArray --file flickr_paris.json`

   This command uses the MongoDB instance running on localhost, and places the photo metadata into the tangelo database, in a collection called flickr_paris.

Now the database should be set up to feed photo data to the Flickr app - reload the page and you should be able to explore Paris through photos. If you are still having trouble, please contact us at tangelo-users@public.kitware.com.

#### Time filter

`` `` Zoom to range Unzoom

#### Hashtag filter

#### Record count limit

####

#### Day filter

Sunday Monday Tuesday Wednesday Thursday Friday Saturday

#### Colormap

Month Day Recency (red-blue) Invert color scale None

#### Glyph size

Recency (earlier is larger) Constant

#### Opacity